@@ -18,4 +18,4 @@ class EbsInUse(NonClusterZombiePolicy):
         for volume in volumes:
             if volume.get('State') == 'in-use':
                 in_use_volumes.append(volume)
-        return in_use_volumes
+        return self._organise_instance_data(in_use_volumes)
